###
# main.rb is the only Simunit file loaded by the Unveil Package manager.
#
# Simunits are not intended to be complex, and the whole code should fit in a single file.
#
#
# For documentation, please direct to:
# http://unveil.gamepedia.com/Package_Simunits
###

class Simunit::Muffinman < Simulation_Event_Unit

	# CHANGE THIS: To the folder name of your Package.
	def package_codename
		:particle_adventures_of_muffinman
	end


    ##
    # Initializes this Simunit.
    # This is called by the simulation engine, never instanced by the user.
    def setup
		# We count how many times we are interacted, to use different pre-interaction messages.
		@pre_interaction_count = -1
    end

    ##
    # Whether this Simunit is still alive or not.
    # Once it returns false once to the system, it will be terminated and cleaned up.
    def alive?
		true
    end


    ##
    # Plays a single loop of simulation.
    # Called on every minute change in the game.
    # This is called 60 times in an hour, 1440 times in a day.
    def simulation_tick
		return unless super


        # ...
    end

	# Returns original item used to deploy this Simunit or,
	# if we weren't deployed once before, create item for the first time.
	def deploy_item
		@deploy_item ||= Item_Token.new(:item, :Muffinman).to_object
	end

	def pre_interaction_message
		# Cycle into the next group of pre-interaction messages.
		@pre_interaction_count += 1 if @pre_interaction_count < Vocab::Muffinman::Preinteraction_Pick_Up.count - 1

		# Return a random pre-interaction message.
		Vocab::Muffinman::Preinteraction_Pick_Up[@pre_interaction_count].sample
	end

	def get_user_choices
		choices = Hash.new

		choices[:pick_up] = Vocab::Pick_Up
		choices[:eat] = Vocab::Eat

		choices
	end

	# When user interacts with this event.
	def user_interact(command)
		# Always call super before our code.
		super(command)

		case command
			when :pick_up
				puts 'deploy_item', deploy_item, deploy_item.name

				# Add item to the party.
				$game_party.gain_item(deploy_item, 1, false, true)

				# Notify of gained item.
				$game_menu.notify_gain_item(event.screen_x - 28, event.screen_y - 28, deploy_item)

				# Terminate ourselves.
				terminate

			when :eat
				# No!! We are too delicious to die!!
				$game_storytelling.msg_say(Vocab::Muffinman::Muffin + ': ' + Vocab::Muffinman::Action_On_Eat)

				# Gain Energy from eating.
				$game_party.leader.mod_ep(10)

				# Terminate ourselves.
				terminate
		end
	end

    ##
    # Procedures once the Simunit is dead and must be deleted.
    def terminate
        super

        # ...
    end

end
